/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_Con__eFhkbMY30pSTdER2YWz9cRw tyObject_Con__eFhkbMY30pSTdER2YWz9cRw;
typedef struct tySequence__bZP29c0SHT9aMkbSl4EFvgCg tySequence__bZP29c0SHT9aMkbSl4EFvgCg;
typedef struct tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA;
typedef struct tySequence__m6h1zim2DFUPFJioFj0P9cg tySequence__m6h1zim2DFUPFJioFj0P9cg;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyTuple__tFiYBoaBrKZKt1Te12yKUQ tyTuple__tFiYBoaBrKZKt1Te12yKUQ;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct NimStringDesc NimStringDesc;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;

/* section: NIM_merge_TYPES */
struct TGenericSeq {
NI len;
NI reserved;
};
typedef NU8 tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ;
struct tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg {
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ kind;
union{
NI dest;
};
};
struct tyObject_Con__eFhkbMY30pSTdER2YWz9cRw {
tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ* code;
NI inTryStmt;
tySequence__bZP29c0SHT9aMkbSl4EFvgCg* blocks;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
};
struct tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA {
NIM_BOOL isTryBlock;
union{
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* label;
tySequence__m6h1zim2DFUPFJioFj0P9cg* breakFixups;
} _isTryBlock_1;
struct {tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* finale;
tySequence__qwqHTkRvwhrRyENtudHQ7g* raiseFixups;
} _isTryBlock_2;
};
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyTuple__tFiYBoaBrKZKt1Te12yKUQ {
NI Field0;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* Field1;
};
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NI tyArray__Bd4h7Ocx9bGTvrKzPIWNlHw[3];
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef NU8 tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ;
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ {
  TGenericSeq Sup;
  tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg data[SEQ_DECL_SIZE];
};
struct tySequence__bZP29c0SHT9aMkbSl4EFvgCg {
  TGenericSeq Sup;
  tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__m6h1zim2DFUPFJioFj0P9cg {
  TGenericSeq Sup;
  tyTuple__tFiYBoaBrKZKt1Te12yKUQ data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__m6h1zim2DFUPFJioFj0P9cg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__bZP29c0SHT9aMkbSl4EFvgCg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, gen__gGw9aM0qGTbTYMOOB416xEA)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genUse__nu33JHavvXsnRHhdnu4oxw)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipTrivials__0NuZltSiPVGMF576lPQqOQ)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_NIMCALL(void, Marker_tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, genMagic__yb09bD37nAJUr80zaRim8Tw)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(void, genAndOr__gGw9aM0qGTbTYMOOB416xEA_2)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NI, forkI__zfeGGy35Zjy67bv7Php9bJg)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, patch__w9ckgqgPWsAveG527LmLpiQ)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, NI p);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(void, genDef__nu33JHavvXsnRHhdnu4oxw_2)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genCall__gGw9aM0qGTbTYMOOB416xEA_3)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseConservative__qAerQ9bftuf70QDk42UIFXg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fn);
N_LIB_PRIVATE N_NIMCALL(void, genBreakOrRaiseAux__Y6s0sJiOLbOfGV0KR9bvN5w)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, NI i, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NI, gotoI__zfeGGy35Zjy67bv7Php9bJg_2)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, genIf__gGw9aM0qGTbTYMOOB416xEA_4)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genCase__gGw9aM0qGTbTYMOOB416xEA_5)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genWhile__gGw9aM0qGTbTYMOOB416xEA_6)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrue__GoY2SMIM9arvGY7ylLiaRHQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, popBlock__eDAfFCByokGb4jEgPA1Mmg)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, NI oldLen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, genBlock__gGw9aM0qGTbTYMOOB416xEA_7)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genReturn__gGw9aM0qGTbTYMOOB416xEA_8)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genImplicitReturn__dyRemX06FqbT5C9cymmRLtw)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c);
N_LIB_PRIVATE N_NIMCALL(void, genRaise__gGw9aM0qGTbTYMOOB416xEA_9)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genBreak__gGw9aM0qGTbTYMOOB416xEA_10)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genTry__gGw9aM0qGTbTYMOOB416xEA_11)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genVarSection__gGw9aM0qGTbTYMOOB416xEA_12)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isSinkParam__Ye2MiAptq3GrXxTQeyXNeA_4ast)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTrees__5GE9abCZqpois6anfudFhKw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, aliases__X88oJcf8606anlqCac3FtQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* field);

/* section: NIM_merge_DATA */
N_LIB_PRIVATE TNimType NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
TNimNode* NimDT___J29b9b9cJiD9aK19cdoA7IwWiyA_isTryBlock[3];
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
N_LIB_PRIVATE TNimType NTI__tFiYBoaBrKZKt1Te12yKUQ_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
N_LIB_PRIVATE TNimType NTI__m6h1zim2DFUPFJioFj0P9cg_;
extern TNimType NTI__fKfcLzXYiz5jNu3NH3Tv8Q_;
extern TNimType NTI__qwqHTkRvwhrRyENtudHQ7g_;
N_LIB_PRIVATE TNimType NTI__bZP29c0SHT9aMkbSl4EFvgCg_;
N_LIB_PRIVATE TNimType NTI__Iclb1njvAJfjjEpCLzUzZg_;
N_LIB_PRIVATE TNimType NTI__kmjEwko0gQNypI4MTa9chwQ_;
TNimNode* NimDT___Iclb1njvAJfjjEpCLzUzZg_kind[5];
N_LIB_PRIVATE TNimType NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_;
STRING_LITERAL(TM__rmUZTUif19aNVU5raHE2xtA_9, "dfa.nim(273, 12) `low(int) div 2 + 1 < c.code.len - p.int and c"
".code.len - p.int < high(int) div 2` ", 100);
STRING_LITERAL(TM__rmUZTUif19aNVU5raHE2xtA_10, "dfa.nim(758, 24) `false` dfa construction pass requires the eli"
"mination of \'defer\'", 82);

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
static N_NIMCALL(void, Marker_tySequence__m6h1zim2DFUPFJioFj0P9cg)(void* p, NI op) {
	tySequence__m6h1zim2DFUPFJioFj0P9cg* a;
	NI T1_;
	a = (tySequence__m6h1zim2DFUPFJioFj0P9cg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__bZP29c0SHT9aMkbSl4EFvgCg)(void* p, NI op) {
	tySequence__bZP29c0SHT9aMkbSl4EFvgCg* a;
	NI T1_;
	a = (tySequence__bZP29c0SHT9aMkbSl4EFvgCg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	switch (a->data[T1_].isTryBlock) {
	case NIM_FALSE:
	nimGCvisit((void*)a->data[T1_]._isTryBlock_1.label, op);
	nimGCvisit((void*)a->data[T1_]._isTryBlock_1.breakFixups, op);
	break;
	case NIM_TRUE:
	nimGCvisit((void*)a->data[T1_]._isTryBlock_2.finale, op);
	nimGCvisit((void*)a->data[T1_]._isTryBlock_2.raiseFixups, op);
	break;
	} 
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipTrivials__0NuZltSiPVGMF576lPQqOQ)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		while (1) {
			switch ((*result).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
			{
				result = (*result)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
			{
				gen__gGw9aM0qGTbTYMOOB416xEA(c, (*result)._kind_6.sons->data[((NI) 1)]);
				result = (*result)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
			{
				result = (*result)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ)(void* p, NI op) {
	tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ* a;
	NI T1_;
	a = (tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].n, op);
	switch (a->data[T1_].kind) {
	case ((tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ) 0):
	case ((tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ) 1):
	break;
	default:
	break;
	} 
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genUse__nu33JHavvXsnRHhdnu4oxw)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	n = skipTrivials__0NuZltSiPVGMF576lPQqOQ(c, orig);
	{
		NIM_BOOL T3_;
		tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg T7_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = ((2100008 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)(&T7_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
		nimZeroMem((void*)(&T7_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
		T7_.n = orig;
		T7_.kind = ((tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ) 3);
		unsureAsgnRef((void**) (&(*c).code), (tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ*) incrSeqV3((TGenericSeq*)((*c).code), (&NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_)));
		T8_ = (*c).code->Sup.len++;
		genericAssign((void*)(&(*c).code->data[T8_]), (void*)(&T7_), (&NTI__Iclb1njvAJfjjEpCLzUzZg_));
	}
	goto LA1_;
	LA5_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA10_;
		gen__gGw9aM0qGTbTYMOOB416xEA(c, n);
	}
	goto LA1_;
	LA10_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, forkI__zfeGGy35Zjy67bv7Php9bJg)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg T2_;
	NI T3_;
	result = (NI)0;
	T1_ = ((*c).code ? (*c).code->Sup.len : 0);
	result = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
	T2_.n = n;
	T2_.kind = ((tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ) 1);
	T2_.dest = ((NI) 0);
	unsureAsgnRef((void**) (&(*c).code), (tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ*) incrSeqV3((TGenericSeq*)((*c).code), (&NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_)));
	T3_ = (*c).code->Sup.len++;
	genericAssign((void*)(&(*c).code->data[T3_]), (void*)(&T2_), (&NTI__Iclb1njvAJfjjEpCLzUzZg_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, patch__w9ckgqgPWsAveG527LmLpiQ)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, NI p) {
	NI T9_;
	{
		NIM_BOOL T3_;
		NI T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = ((*c).code ? (*c).code->Sup.len : 0);
		T3_ = (((NI) IL64(-4611686018427387903)) < (NI)(T4_ - p));
		if (!(T3_)) goto LA5_;
		T6_ = ((*c).code ? (*c).code->Sup.len : 0);
		T3_ = ((NI)(T6_ - p) < ((NI) IL64(4611686018427387903)));
		LA5_: ;
		if (!!(T3_)) goto LA7_;
		failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rmUZTUif19aNVU5raHE2xtA_9));
	}
	LA7_: ;
	T9_ = ((*c).code ? (*c).code->Sup.len : 0);
	(*c).code->data[p].dest = (NI)(T9_ - p);
}
N_LIB_PRIVATE N_NIMCALL(void, genAndOr__gGw9aM0qGTbTYMOOB416xEA_2)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI lab1X60gensym28_;
	gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 1)]);
	lab1X60gensym28_ = forkI__zfeGGy35Zjy67bv7Php9bJg(c, n);
	gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 2)]);
	patch__w9ckgqgPWsAveG527LmLpiQ(c, lab1X60gensym28_);
}
N_LIB_PRIVATE N_NIMCALL(void, genDef__nu33JHavvXsnRHhdnu4oxw_2)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	n = skipTrivials__0NuZltSiPVGMF576lPQqOQ(c, orig);
	{
		NIM_BOOL T3_;
		tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg T7_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = ((2100008 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)(&T7_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
		nimZeroMem((void*)(&T7_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
		T7_.n = orig;
		T7_.kind = ((tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ) 2);
		unsureAsgnRef((void**) (&(*c).code), (tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ*) incrSeqV3((TGenericSeq*)((*c).code), (&NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_)));
		T8_ = (*c).code->Sup.len++;
		genericAssign((void*)(&(*c).code->data[T8_]), (void*)(&T7_), (&NTI__Iclb1njvAJfjjEpCLzUzZg_));
	}
	LA5_: ;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, gotoI__zfeGGy35Zjy67bv7Php9bJg_2)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg T2_;
	NI T3_;
	result = (NI)0;
	T1_ = ((*c).code ? (*c).code->Sup.len : 0);
	result = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
	T2_.n = n;
	T2_.kind = ((tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ) 0);
	T2_.dest = ((NI) 0);
	unsureAsgnRef((void**) (&(*c).code), (tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ*) incrSeqV3((TGenericSeq*)((*c).code), (&NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_)));
	T3_ = (*c).code->Sup.len++;
	genericAssign((void*)(&(*c).code->data[T3_]), (void*)(&T2_), (&NTI__Iclb1njvAJfjjEpCLzUzZg_));
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, genBreakOrRaiseAux__Y6s0sJiOLbOfGV0KR9bvN5w)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, NI i, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI lab1;
	lab1 = gotoI__zfeGGy35Zjy67bv7Php9bJg_2(c, n);
	{
		NI T5_;
		if (!(*c).blocks->data[i].isTryBlock) goto LA3_;
		asgnRef((void**) (&(*c).blocks->data[i]._isTryBlock_2.raiseFixups), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*c).blocks->data[i]._isTryBlock_2.raiseFixups), (&NTI__qwqHTkRvwhrRyENtudHQ7g_)));
		T5_ = (*c).blocks->data[i]._isTryBlock_2.raiseFixups->Sup.len++;
		(*c).blocks->data[i]._isTryBlock_2.raiseFixups->data[T5_] = lab1;
	}
	goto LA1_;
	LA3_: ;
	{
		tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* trailingFinales;
		tyTuple__tFiYBoaBrKZKt1Te12yKUQ T20_;
		NI T21_;
		trailingFinales = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
		{
			if (!(((NI) 0) < (*c).inTryStmt)) goto LA9_;
			{
				NI b;
				NI colontmp_;
				NI T12_;
				NI res;
				b = (NI)0;
				colontmp_ = (NI)0;
				T12_ = (((*c).blocks ? (*c).blocks->Sup.len : 0)-1);
				colontmp_ = T12_;
				res = colontmp_;
				{
					while (1) {
						if (!(i <= res)) goto LA14;
						b = res;
						{
							NI T19_;
							if (!(*c).blocks->data[b].isTryBlock) goto LA17_;
							trailingFinales = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)(trailingFinales), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_));
							T19_ = trailingFinales->Sup.len++;
							asgnRef((void**) (&trailingFinales->data[T19_]), (*c).blocks->data[b]._isTryBlock_2.finale);
						}
						LA17_: ;
						res -= ((NI) 1);
					} LA14: ;
				}
			}
		}
		LA9_: ;
		nimZeroMem((void*)(&T20_), sizeof(tyTuple__tFiYBoaBrKZKt1Te12yKUQ));
		T20_.Field0 = lab1;
		genericSeqAssign((&T20_.Field1), trailingFinales, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_));
		asgnRef((void**) (&(*c).blocks->data[i]._isTryBlock_1.breakFixups), (tySequence__m6h1zim2DFUPFJioFj0P9cg*) incrSeqV3((TGenericSeq*)((*c).blocks->data[i]._isTryBlock_1.breakFixups), (&NTI__m6h1zim2DFUPFJioFj0P9cg_)));
		T21_ = (*c).blocks->data[i]._isTryBlock_1.breakFixups->Sup.len++;
		(*c).blocks->data[i]._isTryBlock_1.breakFixups->data[T21_].Field0 = T20_.Field0;
		genericSeqAssign((&(*c).blocks->data[i]._isTryBlock_1.breakFixups->data[T21_].Field1), T20_.Field1, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCall__gGw9aM0qGTbTYMOOB416xEA_3)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 0)]);
	t = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
	{
		if (!!((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA3_;
		t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
	}
	LA3_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA7;
				i = i_2;
				gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[i]);
				i_2 += ((NI) 1);
			} LA7: ;
		}
	}
	{
		NIM_BOOL T10_;
		NI lab1X60gensym90_;
		T10_ = (NIM_BOOL)0;
		T10_ = (((NI) 0) < (*c).inTryStmt);
		if (!(T10_)) goto LA11_;
		T10_ = canRaiseConservative__qAerQ9bftuf70QDk42UIFXg((*n)._kind_6.sons->data[((NI) 0)]);
		LA11_: ;
		if (!T10_) goto LA12_;
		lab1X60gensym90_ = forkI__zfeGGy35Zjy67bv7Php9bJg(c, n);
		{
			NI i_3;
			NI colontmp__2;
			NI T15_;
			NI res;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			T15_ = (((*c).blocks ? (*c).blocks->Sup.len : 0)-1);
			colontmp__2 = T15_;
			res = colontmp__2;
			{
				while (1) {
					if (!(((NI) 0) <= res)) goto LA17;
					i_3 = res;
					{
						if (!(*c).blocks->data[i_3].isTryBlock) goto LA20_;
						genBreakOrRaiseAux__Y6s0sJiOLbOfGV0KR9bvN5w(c, i_3, n);
						goto LA14;
					}
					LA20_: ;
					res -= ((NI) 1);
				} LA17: ;
			}
		} LA14: ;
		patch__w9ckgqgPWsAveG527LmLpiQ(c, lab1X60gensym90_);
	}
	LA12_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genMagic__yb09bD37nAJUr80zaRim8Tw)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m) {
	switch (m) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 109):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 110):
	{
		genAndOr__gGw9aM0qGTbTYMOOB416xEA_2(c, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 32):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 33):
	{
		genDef__nu33JHavvXsnRHhdnu4oxw_2(c, (*n)._kind_6.sons->data[((NI) 1)]);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 2);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i = i_2;
					gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA5: ;
			}
		}
	}
	break;
	default:
	{
		genCall__gGw9aM0qGTbTYMOOB416xEA_3(c, n);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genIf__gGw9aM0qGTbTYMOOB416xEA_4)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g* endings;
	endings = NIM_NIL;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				gen__gGw9aM0qGTbTYMOOB416xEA(c, (*it)._kind_6.sons->data[((NI) 0)]);
				{
					NI T6_;
					NI lab1X60gensym23_;
					NI T9_;
					NI T10_;
					T6_ = (NI)0;
					T6_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					if (!(T6_ == ((NI) 2))) goto LA7_;
					lab1X60gensym23_ = forkI__zfeGGy35Zjy67bv7Php9bJg(c, (*it)._kind_6.sons->data[((NI) 1)]);
					gen__gGw9aM0qGTbTYMOOB416xEA(c, (*it)._kind_6.sons->data[((NI) 1)]);
					T9_ = (NI)0;
					T9_ = gotoI__zfeGGy35Zjy67bv7Php9bJg_2(c, (*it)._kind_6.sons->data[((NI) 1)]);
					endings = (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)(endings), (&NTI__qwqHTkRvwhrRyENtudHQ7g_));
					T10_ = endings->Sup.len++;
					endings->data[T10_] = T9_;
					patch__w9ckgqgPWsAveG527LmLpiQ(c, lab1X60gensym23_);
				}
				LA7_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		NI i_3;
		NI colontmp__2;
		NI T12_;
		NI res;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		T12_ = ((endings ? endings->Sup.len : 0)-1);
		colontmp__2 = T12_;
		res = colontmp__2;
		{
			while (1) {
				if (!(((NI) 0) <= res)) goto LA14;
				i_3 = res;
				patch__w9ckgqgPWsAveG527LmLpiQ(c, endings->data[i_3]);
				res -= ((NI) 1);
			} LA14: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genCase__gGw9aM0qGTbTYMOOB416xEA_5)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL isExhaustive;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tySequence__qwqHTkRvwhrRyENtudHQ7g* endings;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350144710672));
	isExhaustive = !(((IL64(1031060586496) &((NU64)1<<((NU)((*T1_).kind)&63U)))!=0));
	endings = NIM_NIL;
	gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 0)]);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					NIM_BOOL T7_;
					NI T8_;
					NIM_BOOL T10_;
					NI T11_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
					T7_ = (NIM_BOOL)0;
					T8_ = (NI)0;
					T8_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					T7_ = (T8_ == ((NI) 1));
					if (T7_) goto LA9_;
					T10_ = (NIM_BOOL)0;
					T11_ = (NI)0;
					T11_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
					T10_ = (i == (NI)(T11_ - ((NI) 1)));
					if (!(T10_)) goto LA12_;
					T10_ = isExhaustive;
					LA12_: ;
					T7_ = T10_;
					LA9_: ;
					if (!T7_) goto LA13_;
					T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T15_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
					gen__gGw9aM0qGTbTYMOOB416xEA(c, T15_);
				}
				goto LA5_;
				LA13_: ;
				{
					NI lab1X60gensym34_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T17_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T18_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T19_;
					NI T20_;
					NI T21_;
					T17_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T17_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
					lab1X60gensym34_ = forkI__zfeGGy35Zjy67bv7Php9bJg(c, T17_);
					T18_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T18_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
					gen__gGw9aM0qGTbTYMOOB416xEA(c, T18_);
					T19_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T19_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
					T20_ = (NI)0;
					T20_ = gotoI__zfeGGy35Zjy67bv7Php9bJg_2(c, T19_);
					endings = (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)(endings), (&NTI__qwqHTkRvwhrRyENtudHQ7g_));
					T21_ = endings->Sup.len++;
					endings->data[T21_] = T20_;
					patch__w9ckgqgPWsAveG527LmLpiQ(c, lab1X60gensym34_);
				}
				LA5_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NI i_3;
		NI colontmp__2;
		NI T23_;
		NI res;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		T23_ = ((endings ? endings->Sup.len : 0)-1);
		colontmp__2 = T23_;
		res = colontmp__2;
		{
			while (1) {
				NI endPos;
				if (!(((NI) 0) <= res)) goto LA25;
				i_3 = res;
				endPos = endings->data[i_3];
				patch__w9ckgqgPWsAveG527LmLpiQ(c, endPos);
				res -= ((NI) 1);
			} LA25: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrue__GoY2SMIM9arvGY7ylLiaRHQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	NIM_BOOL T7_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T3_)) goto LA4_;
	T3_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20));
	LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T2_ = !(((*(*n)._kind_4.sym).position == ((NI) 0)));
	LA5_: ;
	T1_ = T2_;
	if (T1_) goto LA6_;
	T7_ = (NIM_BOOL)0;
	T7_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6));
	if (!(T7_)) goto LA8_;
	T7_ = !(((*n)._kind_1.intVal == IL64(0)));
	LA8_: ;
	T1_ = T7_;
	LA6_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, popBlock__eDAfFCByokGb4jEgPA1Mmg)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, NI oldLen) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g* exits;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	NI T2_;
	NI T3_;
	exits = (tySequence__qwqHTkRvwhrRyENtudHQ7g*)0;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
	T2_ = (NI)0;
	T2_ = gotoI__zfeGGy35Zjy67bv7Php9bJg_2(c, T1_);
	exits = (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)(exits), (&NTI__qwqHTkRvwhrRyENtudHQ7g_));
	T3_ = exits->Sup.len++;
	exits->data[T3_] = T2_;
	{
		tyTuple__tFiYBoaBrKZKt1Te12yKUQ* f;
		tySequence__m6h1zim2DFUPFJioFj0P9cg* colontmp_;
		NI i;
		NI L;
		NI T5_;
		f = (tyTuple__tFiYBoaBrKZKt1Te12yKUQ*)0;
		colontmp_ = (tySequence__m6h1zim2DFUPFJioFj0P9cg*)0;
		colontmp_ = (*c).blocks->data[oldLen]._isTryBlock_1.breakFixups;
		i = ((NI) 0);
		T5_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T5_;
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T12_;
				NI T13_;
				NI T14_;
				if (!(i < L)) goto LA7;
				f = (&colontmp_->data[i]);
				patch__w9ckgqgPWsAveG527LmLpiQ(c, (*f).Field0);
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** finale;
					tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp__2;
					NI i_2;
					NI L_2;
					NI T9_;
					finale = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
					colontmp__2 = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
					colontmp__2 = (*f).Field1;
					i_2 = ((NI) 0);
					T9_ = (colontmp__2 ? colontmp__2->Sup.len : 0);
					L_2 = T9_;
					{
						while (1) {
							if (!(i_2 < L_2)) goto LA11;
							finale = &colontmp__2->data[i_2];
							gen__gGw9aM0qGTbTYMOOB416xEA(c, (*finale));
							i_2 += ((NI) 1);
						} LA11: ;
					}
				}
				T12_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T12_ = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
				T13_ = (NI)0;
				T13_ = gotoI__zfeGGy35Zjy67bv7Php9bJg_2(c, T12_);
				exits = (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)(exits), (&NTI__qwqHTkRvwhrRyENtudHQ7g_));
				T14_ = exits->Sup.len++;
				exits->data[T14_] = T13_;
				i += ((NI) 1);
			} LA7: ;
		}
	}
	{
		NI* e;
		NI i_3;
		NI L_3;
		NI T16_;
		e = (NI*)0;
		i_3 = ((NI) 0);
		T16_ = (exits ? exits->Sup.len : 0);
		L_3 = T16_;
		{
			while (1) {
				if (!(i_3 < L_3)) goto LA18;
				e = (&exits->data[i_3]);
				patch__w9ckgqgPWsAveG527LmLpiQ(c, (*e));
				i_3 += ((NI) 1);
			} LA18: ;
		}
	}
	unsureAsgnRef((void**) (&(*c).blocks), (tySequence__bZP29c0SHT9aMkbSl4EFvgCg*) setLengthSeqV2(&((*c).blocks)->Sup, (&NTI__bZP29c0SHT9aMkbSl4EFvgCg_), ((NI) (oldLen))));
}
N_LIB_PRIVATE N_NIMCALL(void, genWhile__gGw9aM0qGTbTYMOOB416xEA_6)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NI oldLenX60gensym16_;
		NI T6_;
		tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA T7_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTrue__GoY2SMIM9arvGY7ylLiaRHQ((*n)._kind_6.sons->data[((NI) 0)]);
		if (!T3_) goto LA4_;
		T6_ = ((*c).blocks ? (*c).blocks->Sup.len : 0);
		oldLenX60gensym16_ = T6_;
		nimZeroMem((void*)(&T7_), sizeof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA));
		nimZeroMem((void*)(&T7_), sizeof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA));
		T7_.isTryBlock = NIM_FALSE;
		T7_._isTryBlock_1.label = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		unsureAsgnRef((void**) (&(*c).blocks), (tySequence__bZP29c0SHT9aMkbSl4EFvgCg*) incrSeqV3((TGenericSeq*)((*c).blocks), (&NTI__bZP29c0SHT9aMkbSl4EFvgCg_)));
		T8_ = (*c).blocks->Sup.len++;
		genericAssign((void*)(&(*c).blocks->data[T8_]), (void*)(&T7_), (&NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_));
		{
			NI i;
			NI res;
			i = (NI)0;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= ((NI) 2))) goto LA11;
					i = res;
					gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 1)]);
					res += ((NI) 1);
				} LA11: ;
			}
		}
		popBlock__eDAfFCByokGb4jEgPA1Mmg(c, oldLenX60gensym16_);
	}
	goto LA1_;
	LA4_: ;
	{
		NI oldLenX60gensym18_;
		NI T13_;
		tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA T14_;
		NI T15_;
		tyArray__Bd4h7Ocx9bGTvrKzPIWNlHw endings;
		T13_ = ((*c).blocks ? (*c).blocks->Sup.len : 0);
		oldLenX60gensym18_ = T13_;
		nimZeroMem((void*)(&T14_), sizeof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA));
		nimZeroMem((void*)(&T14_), sizeof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA));
		T14_.isTryBlock = NIM_FALSE;
		T14_._isTryBlock_1.label = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		unsureAsgnRef((void**) (&(*c).blocks), (tySequence__bZP29c0SHT9aMkbSl4EFvgCg*) incrSeqV3((TGenericSeq*)((*c).blocks), (&NTI__bZP29c0SHT9aMkbSl4EFvgCg_)));
		T15_ = (*c).blocks->Sup.len++;
		genericAssign((void*)(&(*c).blocks->data[T15_]), (void*)(&T14_), (&NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_));
		nimZeroMem((void*)endings, sizeof(tyArray__Bd4h7Ocx9bGTvrKzPIWNlHw));
		{
			NI i_2;
			NI res_2;
			i_2 = (NI)0;
			res_2 = ((NI) 0);
			{
				while (1) {
					if (!(res_2 <= ((NI) 2))) goto LA18;
					i_2 = res_2;
					gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 0)]);
					endings[(i_2)- 0] = forkI__zfeGGy35Zjy67bv7Php9bJg(c, n);
					gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 1)]);
					res_2 += ((NI) 1);
				} LA18: ;
			}
		}
		{
			NI i_3;
			NI res_3;
			i_3 = (NI)0;
			res_3 = ((NI) 2);
			{
				while (1) {
					if (!(((NI) 0) <= res_3)) goto LA21;
					i_3 = ((NI) (res_3));
					patch__w9ckgqgPWsAveG527LmLpiQ(c, endings[(i_3)- 0]);
					res_3 -= ((NI) 1);
				} LA21: ;
			}
		}
		popBlock__eDAfFCByokGb4jEgPA1Mmg(c, oldLenX60gensym18_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBlock__gGw9aM0qGTbTYMOOB416xEA_7)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI oldLenX60gensym36_;
	NI T1_;
	tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA T2_;
	NI T3_;
	T1_ = ((*c).blocks ? (*c).blocks->Sup.len : 0);
	oldLenX60gensym36_ = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA));
	T2_.isTryBlock = NIM_FALSE;
	T2_._isTryBlock_1.label = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	unsureAsgnRef((void**) (&(*c).blocks), (tySequence__bZP29c0SHT9aMkbSl4EFvgCg*) incrSeqV3((TGenericSeq*)((*c).blocks), (&NTI__bZP29c0SHT9aMkbSl4EFvgCg_)));
	T3_ = (*c).blocks->Sup.len++;
	genericAssign((void*)(&(*c).blocks->data[T3_]), (void*)(&T2_), (&NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_));
	gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 1)]);
	popBlock__eDAfFCByokGb4jEgPA1Mmg(c, oldLenX60gensym36_);
}
N_LIB_PRIVATE N_NIMCALL(void, genImplicitReturn__dyRemX06FqbT5C9cymmRLtw)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((126976 &((NU32)1<<((NU)((*(*c).owner).kind)&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*c).owner).ast);
		T3_ = (((NI) 7) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		gen__gGw9aM0qGTbTYMOOB416xEA(c, (*(*(*c).owner).ast)._kind_6.sons->data[((NI) 7)]);
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genReturn__gGw9aM0qGTbTYMOOB416xEA_8)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA3_;
		gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	goto LA1_;
	LA3_: ;
	{
		genImplicitReturn__dyRemX06FqbT5C9cymmRLtw(c);
	}
	LA1_: ;
	genBreakOrRaiseAux__Y6s0sJiOLbOfGV0KR9bvN5w(c, ((NI) 0), n);
}
N_LIB_PRIVATE N_NIMCALL(void, genRaise__gGw9aM0qGTbTYMOOB416xEA_9)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
{	gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 0)]);
	{
		if (!(((NI) 0) < (*c).inTryStmt)) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI T6_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T6_ = (((*c).blocks ? (*c).blocks->Sup.len : 0)-1);
			colontmp_ = T6_;
			res = colontmp_;
			{
				while (1) {
					if (!(((NI) 0) <= res)) goto LA8;
					i = res;
					{
						if (!(*c).blocks->data[i].isTryBlock) goto LA11_;
						genBreakOrRaiseAux__Y6s0sJiOLbOfGV0KR9bvN5w(c, i, n);
						goto BeforeRet_;
					}
					LA11_: ;
					res -= ((NI) 1);
				} LA8: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg T14_;
		NI T15_;
		NI T16_;
		nimZeroMem((void*)(&T14_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
		nimZeroMem((void*)(&T14_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
		T14_.n = n;
		T14_.kind = ((tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ) 0);
		T15_ = ((*c).code ? (*c).code->Sup.len : 0);
		T14_.dest = (NI)(((NI) IL64(9223372036854775807)) - T15_);
		unsureAsgnRef((void**) (&(*c).code), (tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ*) incrSeqV3((TGenericSeq*)((*c).code), (&NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_)));
		T16_ = (*c).code->Sup.len++;
		genericAssign((void*)(&(*c).code->data[T16_]), (void*)(&T14_), (&NTI__Iclb1njvAJfjjEpCLzUzZg_));
	}
	LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBreak__gGw9aM0qGTbTYMOOB416xEA_10)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
{	{
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI T6_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T6_ = (((*c).blocks ? (*c).blocks->Sup.len : 0)-1);
			colontmp_ = T6_;
			res = colontmp_;
			{
				while (1) {
					if (!(((NI) 0) <= res)) goto LA8;
					i = res;
					{
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = !((*c).blocks->data[i].isTryBlock);
						if (!(T11_)) goto LA12_;
						T11_ = ((*c).blocks->data[i]._isTryBlock_1.label == (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
						LA12_: ;
						if (!T11_) goto LA13_;
						genBreakOrRaiseAux__Y6s0sJiOLbOfGV0KR9bvN5w(c, i, n);
						goto BeforeRet_;
					}
					LA13_: ;
					res -= ((NI) 1);
				} LA8: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI i_2;
			NI colontmp__2;
			NI T17_;
			NI res_2;
			i_2 = (NI)0;
			colontmp__2 = (NI)0;
			T17_ = (((*c).blocks ? (*c).blocks->Sup.len : 0)-1);
			colontmp__2 = T17_;
			res_2 = colontmp__2;
			{
				while (1) {
					if (!(((NI) 0) <= res_2)) goto LA19;
					i_2 = res_2;
					{
						if (!!((*c).blocks->data[i_2].isTryBlock)) goto LA22_;
						genBreakOrRaiseAux__Y6s0sJiOLbOfGV0KR9bvN5w(c, i_2, n);
						goto BeforeRet_;
					}
					LA22_: ;
					res_2 -= ((NI) 1);
				} LA19: ;
			}
		}
	}
	LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTry__gGw9aM0qGTbTYMOOB416xEA_11)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g* endings;
	NI oldLen;
	NI T1_;
	tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA T2_;
	NI T10_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fin;
	endings = NIM_NIL;
	T1_ = ((*c).blocks ? (*c).blocks->Sup.len : 0);
	oldLen = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA));
	T2_.isTryBlock = NIM_TRUE;
	{
		NI T5_;
		NI T8_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!((*(*n)._kind_6.sons->data[(NI)(T5_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107))) goto LA6_;
		T8_ = (NI)0;
		T8_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T2_._isTryBlock_2.finale = (*n)._kind_6.sons->data[(NI)(T8_ - ((NI) 1))];
	}
	goto LA3_;
	LA6_: ;
	{
		T2_._isTryBlock_2.finale = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*c).blocks), (tySequence__bZP29c0SHT9aMkbSl4EFvgCg*) incrSeqV3((TGenericSeq*)((*c).blocks), (&NTI__bZP29c0SHT9aMkbSl4EFvgCg_)));
	T10_ = (*c).blocks->Sup.len++;
	genericAssign((void*)(&(*c).blocks->data[T10_]), (void*)(&T2_), (&NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_));
	(*c).inTryStmt += ((NI) 1);
	gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 0)]);
	(*c).inTryStmt -= ((NI) 1);
	{
		NI* f;
		tySequence__qwqHTkRvwhrRyENtudHQ7g* colontmp_;
		NI i;
		NI L;
		NI T12_;
		f = (NI*)0;
		colontmp_ = (tySequence__qwqHTkRvwhrRyENtudHQ7g*)0;
		colontmp_ = (*c).blocks->data[oldLen]._isTryBlock_2.raiseFixups;
		i = ((NI) 0);
		T12_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T12_;
		{
			while (1) {
				if (!(i < L)) goto LA14;
				f = (&colontmp_->data[i]);
				patch__w9ckgqgPWsAveG527LmLpiQ(c, (*f));
				i += ((NI) 1);
			} LA14: ;
		}
	}
	unsureAsgnRef((void**) (&(*c).blocks), (tySequence__bZP29c0SHT9aMkbSl4EFvgCg*) setLengthSeqV2(&((*c).blocks)->Sup, (&NTI__bZP29c0SHT9aMkbSl4EFvgCg_), ((NI) (oldLen))));
	{
		NI i_2;
		NI colontmp__2;
		NI i_3;
		i_2 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_3 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_3 < colontmp__2)) goto LA17;
				i_2 = i_3;
				it = (*n)._kind_6.sons->data[i_2];
				{
					NI lab1X60gensym50_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T22_;
					NI T23_;
					NI T24_;
					if (!!(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107)))) goto LA20_;
					lab1X60gensym50_ = forkI__zfeGGy35Zjy67bv7Php9bJg(c, it);
					T22_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T22_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
					gen__gGw9aM0qGTbTYMOOB416xEA(c, T22_);
					T23_ = (NI)0;
					T23_ = gotoI__zfeGGy35Zjy67bv7Php9bJg_2(c, it);
					endings = (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)(endings), (&NTI__qwqHTkRvwhrRyENtudHQ7g_));
					T24_ = endings->Sup.len++;
					endings->data[T24_] = T23_;
					patch__w9ckgqgPWsAveG527LmLpiQ(c, lab1X60gensym50_);
				}
				LA20_: ;
				i_3 += ((NI) 1);
			} LA17: ;
		}
	}
	{
		NI i_4;
		NI colontmp__3;
		NI T26_;
		NI res;
		i_4 = (NI)0;
		colontmp__3 = (NI)0;
		T26_ = ((endings ? endings->Sup.len : 0)-1);
		colontmp__3 = T26_;
		res = colontmp__3;
		{
			while (1) {
				if (!(((NI) 0) <= res)) goto LA28;
				i_4 = res;
				patch__w9ckgqgPWsAveG527LmLpiQ(c, endings->data[i_4]);
				res -= ((NI) 1);
			} LA28: ;
		}
	}
	fin = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
	{
		if (!((*fin).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107))) goto LA31_;
		gen__gGw9aM0qGTbTYMOOB416xEA(c, (*fin)._kind_6.sons->data[((NI) 0)]);
	}
	LA31_: ;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarSection__gGw9aM0qGTbTYMOOB416xEA_12)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
		a = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA7_;
					}
					goto LA5_;
					LA7_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T12_;
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA10_;
						T12_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T12_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(a);
						gen__gGw9aM0qGTbTYMOOB416xEA(c, T12_);
						{
							NI i_3;
							NI colontmp__2;
							NI T14_;
							NI i_4;
							i_3 = (NI)0;
							colontmp__2 = (NI)0;
							T14_ = (NI)0;
							T14_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
							colontmp__2 = (NI)(T14_ - ((NI) 2));
							i_4 = ((NI) 0);
							{
								while (1) {
									if (!(i_4 < colontmp__2)) goto LA16;
									i_3 = i_4;
									genDef__nu33JHavvXsnRHhdnu4oxw_2(c, (*a)._kind_6.sons->data[i_3]);
									i_4 += ((NI) 1);
								} LA16: ;
							}
						}
					}
					goto LA5_;
					LA10_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T18_;
						T18_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T18_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(a);
						gen__gGw9aM0qGTbTYMOOB416xEA(c, T18_);
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T21_;
							T21_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T21_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(a);
							if (!!(((*T21_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA22_;
							genDef__nu33JHavvXsnRHhdnu4oxw_2(c, (*a)._kind_6.sons->data[((NI) 0)]);
						}
						LA22_: ;
					}
					LA5_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, gen__gGw9aM0qGTbTYMOOB416xEA)(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		genUse__nu33JHavvXsnRHhdnu4oxw(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA5_;
			s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			{
				if (!!(((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)))) goto LA9_;
				genMagic__yb09bD37nAJUr80zaRim8Tw(c, n, (*s).magic);
			}
			goto LA7_;
			LA9_: ;
			{
				genCall__gGw9aM0qGTbTYMOOB416xEA_3(c, n);
			}
			LA7_: ;
			{
				tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg T16_;
				NI T17_;
				NI T18_;
				if (!(((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 16))&63U)))!=0)) goto LA14_;
				nimZeroMem((void*)(&T16_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
				nimZeroMem((void*)(&T16_), sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg));
				T16_.n = n;
				T16_.kind = ((tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ) 0);
				T17_ = ((*c).code ? (*c).code->Sup.len : 0);
				T16_.dest = (NI)(((NI) IL64(9223372036854775807)) - T17_);
				unsureAsgnRef((void**) (&(*c).code), (tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ*) incrSeqV3((TGenericSeq*)((*c).code), (&NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_)));
				T18_ = (*c).code->Sup.len++;
				genericAssign((void*)(&(*c).code->data[T18_]), (void*)(&T16_), (&NTI__Iclb1njvAJfjjEpCLzUzZg_));
			}
			LA14_: ;
		}
		goto LA3_;
		LA5_: ;
		{
			genCall__gGw9aM0qGTbTYMOOB416xEA_3(c, n);
		}
		LA3_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 1)]);
		genDef__nu33JHavvXsnRHhdnu4oxw_2(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
	{
		genUse__nu33JHavvXsnRHhdnu4oxw(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48):
	{
		genIf__gGw9aM0qGTbTYMOOB416xEA_4(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	{
		gen__gGw9aM0qGTbTYMOOB416xEA(c, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		genCase__gGw9aM0qGTbTYMOOB416xEA_5(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		genWhile__gGw9aM0qGTbTYMOOB416xEA_6(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	{
		genBlock__gGw9aM0qGTbTYMOOB416xEA_7(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	{
		genReturn__gGw9aM0qGTbTYMOOB416xEA_8(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108):
	{
		genRaise__gGw9aM0qGTbTYMOOB416xEA_9(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110):
	{
		genBreak__gGw9aM0qGTbTYMOOB416xEA_10(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154):
	{
		genTry__gGw9aM0qGTbTYMOOB416xEA_11(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 68):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 69):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 70):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 104):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
			x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA36;
						i = i_2;
						x = (*n)._kind_6.sons->data[i];
						gen__gGw9aM0qGTbTYMOOB416xEA(c, x);
						i_2 += ((NI) 1);
					} LA36: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 91):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T38_;
		T38_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T38_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
		gen__gGw9aM0qGTbTYMOOB416xEA(c, T38_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 114):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 71):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 72):
	{
		gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 33):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
	{
		gen__gGw9aM0qGTbTYMOOB416xEA(c, (*n)._kind_6.sons->data[((NI) 1)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		genVarSection__gGw9aM0qGTbTYMOOB416xEA_12(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 105):
	{
		{
			if (!NIM_TRUE) goto LA45_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rmUZTUif19aNVU5raHE2xtA_10));
		}
		LA45_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ*, constructCfg__gYr9aUQRxyROXIIqCy8VmDg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body) {
	tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ* result;
	tyObject_Con__eFhkbMY30pSTdER2YWz9cRw c;
	NI oldLenX60gensym110_;
	NI T1_;
	tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA T2_;
	NI T3_;
	result = (tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ*)0;
	nimZeroMem((void*)(&c), sizeof(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw));
	nimZeroMem((void*)(&c), sizeof(tyObject_Con__eFhkbMY30pSTdER2YWz9cRw));
	c.code = NIM_NIL;
	c.blocks = NIM_NIL;
	c.owner = s;
	T1_ = (c.blocks ? c.blocks->Sup.len : 0);
	oldLenX60gensym110_ = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA));
	T2_.isTryBlock = NIM_FALSE;
	T2_._isTryBlock_1.label = s;
	c.blocks = (tySequence__bZP29c0SHT9aMkbSl4EFvgCg*) incrSeqV3((TGenericSeq*)(c.blocks), (&NTI__bZP29c0SHT9aMkbSl4EFvgCg_));
	T3_ = c.blocks->Sup.len++;
	genericAssign((void*)(&c.blocks->data[T3_]), (void*)(&T2_), (&NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_));
	gen__gGw9aM0qGTbTYMOOB416xEA((&c), body);
	genImplicitReturn__dyRemX06FqbT5C9cymmRLtw((&c));
	popBlock__eDAfFCByokGb4jEgPA1Mmg((&c), oldLenX60gensym110_);
	result = c.code;
	return result;
}
static N_INLINE(NIM_BOOL, isSinkParam__Ye2MiAptq3GrXxTQeyXNeA_4ast)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46));
	if (T3_) goto LA4_;
	T3_ = (((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 4))&63U)))!=0);
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isAnalysableFieldAccess__scxG86YRKjb7mFYULG1CyQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	NIM_BOOL T21_;
	NIM_BOOL T22_;
	NIM_BOOL T23_;
	NIM_BOOL T27_;
{	result = (NIM_BOOL)0;
	n = orig;
	{
		while (1) {
			switch ((*n).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
			{
				n = (*n)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
			{
				n = (*n)._kind_6.sons->data[((NI) 1)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
			{
				{
					NIM_BOOL T8_;
					NI T9_;
					T8_ = (NIM_BOOL)0;
					T9_ = (NI)0;
					T9_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
					T8_ = (((NI) 1) < T9_);
					if (!(T8_)) goto LA10_;
					T8_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*(*n)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15));
					LA10_: ;
					if (!T8_) goto LA11_;
					n = (*n)._kind_6.sons->data[((NI) 0)];
				}
				goto LA6_;
				LA11_: ;
				{
					result = NIM_FALSE;
					goto BeforeRet_;
				}
				LA6_: ;
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
			{
				NIM_BOOL T15_;
				NIM_BOOL T16_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T19_;
				n = (*n)._kind_6.sons->data[((NI) 0)];
				T15_ = (NIM_BOOL)0;
				T16_ = (NIM_BOOL)0;
				T16_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T16_)) goto LA17_;
				T16_ = ((*(*n)._kind_4.sym).owner == owner);
				LA17_: ;
				T15_ = T16_;
				if (!(T15_)) goto LA18_;
				T19_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T19_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_4.sym).typ, IL64(36099165763184912));
				T15_ = ((IL64(35184372088832) &((NU64)1<<((NU)((*T19_).kind)&63U)))!=0);
				LA18_: ;
				result = T15_;
				goto BeforeRet_;
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	T21_ = (NIM_BOOL)0;
	T22_ = (NIM_BOOL)0;
	T23_ = (NIM_BOOL)0;
	T23_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T23_)) goto LA24_;
	T23_ = ((*(*n)._kind_4.sym).owner == owner);
	LA24_: ;
	T22_ = T23_;
	if (!(T22_)) goto LA25_;
	T22_ = ((IL64(1099578736648) & (*(*n)._kind_4.sym).flags) == 0);
	LA25_: ;
	T21_ = T22_;
	if (!(T21_)) goto LA26_;
	T27_ = (NIM_BOOL)0;
	T27_ = !(((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3)));
	if (T27_) goto LA28_;
	T27_ = isSinkParam__Ye2MiAptq3GrXxTQeyXNeA_4ast((*n)._kind_4.sym);
	LA28_: ;
	T21_ = T27_;
	LA26_: ;
	result = T21_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConvDfa__vedgqlRdnLUAAjvLVHCgqg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		while (1) {
			switch ((*result).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
			{
				result = (*result)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
			{
				result = (*result)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, aliases__X88oJcf8606anlqCac3FtQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* field) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj_2;
{	result = (NIM_BOOL)0;
	n = field;
	obj_2 = obj;
	{
		while (1) {
			switch ((*obj_2).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
			{
				obj_2 = (*obj_2)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
			{
				obj_2 = (*obj_2)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	{
		while (1) {
			{
				NIM_BOOL T10_;
				T10_ = (NIM_BOOL)0;
				T10_ = sameTrees__5GE9abCZqpois6anfudFhKw(obj_2, n);
				if (!T10_) goto LA11_;
				result = NIM_TRUE;
				goto BeforeRet_;
			}
			LA11_: ;
			switch ((*n).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
			{
				n = (*n)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
			{
				n = (*n)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				goto LA6;
			}
			break;
			}
		}
	} LA6: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ, instrTargets__w1KaHRCZ7rX9a4bWRvZGRmQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* insloc, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* loc) {
	tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ result;
	result = (tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameTrees__5GE9abCZqpois6anfudFhKw(insloc, loc);
		if (T3_) goto LA4_;
		T3_ = aliases__X88oJcf8606anlqCac3FtQ(insloc, loc);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = ((tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ) 1);
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = aliases__X88oJcf8606anlqCac3FtQ(loc, insloc);
		if (!T8_) goto LA9_;
		result = ((tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ) 2);
	}
	goto LA1_;
	LA9_: ;
	{
		result = ((tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ) 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_dfaDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__rmUZTUif19aNVU5raHE2xtA_2_2[2];
static TNimNode* TM__rmUZTUif19aNVU5raHE2xtA_3_2[2];
static TNimNode* TM__rmUZTUif19aNVU5raHE2xtA_4_2[2];
static TNimNode* TM__rmUZTUif19aNVU5raHE2xtA_5_2[2];
static TNimNode* TM__rmUZTUif19aNVU5raHE2xtA_6_4[4];
NI TM__rmUZTUif19aNVU5raHE2xtA_8;
static char* NIM_CONST TM__rmUZTUif19aNVU5raHE2xtA_7[4] = {
"goto", 
"fork", 
"def", 
"use"};
static TNimNode TM__rmUZTUif19aNVU5raHE2xtA_0[20];

/* section: NIM_merge_TYPE_INIT3 */
NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_.size = sizeof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA);
NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_.align = NIM_ALIGNOF(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA);
NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_.kind = 18;
NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_.base = 0;
NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_.flags = 2;
TM__rmUZTUif19aNVU5raHE2xtA_0[0].kind = 3;
TM__rmUZTUif19aNVU5raHE2xtA_0[0].offset = offsetof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA, isTryBlock);
TM__rmUZTUif19aNVU5raHE2xtA_0[0].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__rmUZTUif19aNVU5raHE2xtA_0[0].name = "isTryBlock";
TM__rmUZTUif19aNVU5raHE2xtA_0[0].sons = &NimDT___J29b9b9cJiD9aK19cdoA7IwWiyA_isTryBlock[0];
TM__rmUZTUif19aNVU5raHE2xtA_0[0].len = 2;
TM__rmUZTUif19aNVU5raHE2xtA_2_2[0] = &TM__rmUZTUif19aNVU5raHE2xtA_0[2];
TM__rmUZTUif19aNVU5raHE2xtA_0[2].kind = 1;
TM__rmUZTUif19aNVU5raHE2xtA_0[2].offset = offsetof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA, _isTryBlock_1.label);
TM__rmUZTUif19aNVU5raHE2xtA_0[2].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__rmUZTUif19aNVU5raHE2xtA_0[2].name = "label";
TM__rmUZTUif19aNVU5raHE2xtA_2_2[1] = &TM__rmUZTUif19aNVU5raHE2xtA_0[3];
NTI__tFiYBoaBrKZKt1Te12yKUQ_.size = sizeof(tyTuple__tFiYBoaBrKZKt1Te12yKUQ);
NTI__tFiYBoaBrKZKt1Te12yKUQ_.align = NIM_ALIGNOF(tyTuple__tFiYBoaBrKZKt1Te12yKUQ);
NTI__tFiYBoaBrKZKt1Te12yKUQ_.kind = 18;
NTI__tFiYBoaBrKZKt1Te12yKUQ_.base = 0;
NTI__tFiYBoaBrKZKt1Te12yKUQ_.flags = 2;
TM__rmUZTUif19aNVU5raHE2xtA_3_2[0] = &TM__rmUZTUif19aNVU5raHE2xtA_0[5];
TM__rmUZTUif19aNVU5raHE2xtA_0[5].kind = 1;
TM__rmUZTUif19aNVU5raHE2xtA_0[5].offset = offsetof(tyTuple__tFiYBoaBrKZKt1Te12yKUQ, Field0);
TM__rmUZTUif19aNVU5raHE2xtA_0[5].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__rmUZTUif19aNVU5raHE2xtA_0[5].name = "Field0";
TM__rmUZTUif19aNVU5raHE2xtA_3_2[1] = &TM__rmUZTUif19aNVU5raHE2xtA_0[6];
TM__rmUZTUif19aNVU5raHE2xtA_0[6].kind = 1;
TM__rmUZTUif19aNVU5raHE2xtA_0[6].offset = offsetof(tyTuple__tFiYBoaBrKZKt1Te12yKUQ, Field1);
TM__rmUZTUif19aNVU5raHE2xtA_0[6].typ = (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_);
TM__rmUZTUif19aNVU5raHE2xtA_0[6].name = "Field1";
TM__rmUZTUif19aNVU5raHE2xtA_0[4].len = 2; TM__rmUZTUif19aNVU5raHE2xtA_0[4].kind = 2; TM__rmUZTUif19aNVU5raHE2xtA_0[4].sons = &TM__rmUZTUif19aNVU5raHE2xtA_3_2[0];
NTI__tFiYBoaBrKZKt1Te12yKUQ_.node = &TM__rmUZTUif19aNVU5raHE2xtA_0[4];
NTI__m6h1zim2DFUPFJioFj0P9cg_.size = sizeof(tySequence__m6h1zim2DFUPFJioFj0P9cg*);
NTI__m6h1zim2DFUPFJioFj0P9cg_.align = NIM_ALIGNOF(tySequence__m6h1zim2DFUPFJioFj0P9cg*);
NTI__m6h1zim2DFUPFJioFj0P9cg_.kind = 24;
NTI__m6h1zim2DFUPFJioFj0P9cg_.base = (&NTI__tFiYBoaBrKZKt1Te12yKUQ_);
NTI__m6h1zim2DFUPFJioFj0P9cg_.flags = 2;
NTI__m6h1zim2DFUPFJioFj0P9cg_.marker = Marker_tySequence__m6h1zim2DFUPFJioFj0P9cg;
TM__rmUZTUif19aNVU5raHE2xtA_0[3].kind = 1;
TM__rmUZTUif19aNVU5raHE2xtA_0[3].offset = offsetof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA, _isTryBlock_1.breakFixups);
TM__rmUZTUif19aNVU5raHE2xtA_0[3].typ = (&NTI__m6h1zim2DFUPFJioFj0P9cg_);
TM__rmUZTUif19aNVU5raHE2xtA_0[3].name = "breakFixups";
TM__rmUZTUif19aNVU5raHE2xtA_0[1].len = 2; TM__rmUZTUif19aNVU5raHE2xtA_0[1].kind = 2; TM__rmUZTUif19aNVU5raHE2xtA_0[1].sons = &TM__rmUZTUif19aNVU5raHE2xtA_2_2[0];
NimDT___J29b9b9cJiD9aK19cdoA7IwWiyA_isTryBlock[0] = &TM__rmUZTUif19aNVU5raHE2xtA_0[1];
TM__rmUZTUif19aNVU5raHE2xtA_4_2[0] = &TM__rmUZTUif19aNVU5raHE2xtA_0[8];
TM__rmUZTUif19aNVU5raHE2xtA_0[8].kind = 1;
TM__rmUZTUif19aNVU5raHE2xtA_0[8].offset = offsetof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA, _isTryBlock_2.finale);
TM__rmUZTUif19aNVU5raHE2xtA_0[8].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__rmUZTUif19aNVU5raHE2xtA_0[8].name = "finale";
TM__rmUZTUif19aNVU5raHE2xtA_4_2[1] = &TM__rmUZTUif19aNVU5raHE2xtA_0[9];
TM__rmUZTUif19aNVU5raHE2xtA_0[9].kind = 1;
TM__rmUZTUif19aNVU5raHE2xtA_0[9].offset = offsetof(tyObject_TBlock__J29b9b9cJiD9aK19cdoA7IwWiyA, _isTryBlock_2.raiseFixups);
TM__rmUZTUif19aNVU5raHE2xtA_0[9].typ = (&NTI__qwqHTkRvwhrRyENtudHQ7g_);
TM__rmUZTUif19aNVU5raHE2xtA_0[9].name = "raiseFixups";
TM__rmUZTUif19aNVU5raHE2xtA_0[7].len = 2; TM__rmUZTUif19aNVU5raHE2xtA_0[7].kind = 2; TM__rmUZTUif19aNVU5raHE2xtA_0[7].sons = &TM__rmUZTUif19aNVU5raHE2xtA_4_2[0];
NimDT___J29b9b9cJiD9aK19cdoA7IwWiyA_isTryBlock[1] = &TM__rmUZTUif19aNVU5raHE2xtA_0[7];
NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_.node = &TM__rmUZTUif19aNVU5raHE2xtA_0[0];
NTI__bZP29c0SHT9aMkbSl4EFvgCg_.size = sizeof(tySequence__bZP29c0SHT9aMkbSl4EFvgCg*);
NTI__bZP29c0SHT9aMkbSl4EFvgCg_.align = NIM_ALIGNOF(tySequence__bZP29c0SHT9aMkbSl4EFvgCg*);
NTI__bZP29c0SHT9aMkbSl4EFvgCg_.kind = 24;
NTI__bZP29c0SHT9aMkbSl4EFvgCg_.base = (&NTI__J29b9b9cJiD9aK19cdoA7IwWiyA_);
NTI__bZP29c0SHT9aMkbSl4EFvgCg_.flags = 2;
NTI__bZP29c0SHT9aMkbSl4EFvgCg_.marker = Marker_tySequence__bZP29c0SHT9aMkbSl4EFvgCg;
NTI__Iclb1njvAJfjjEpCLzUzZg_.size = sizeof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg);
NTI__Iclb1njvAJfjjEpCLzUzZg_.align = NIM_ALIGNOF(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg);
NTI__Iclb1njvAJfjjEpCLzUzZg_.kind = 18;
NTI__Iclb1njvAJfjjEpCLzUzZg_.base = 0;
NTI__Iclb1njvAJfjjEpCLzUzZg_.flags = 2;
TM__rmUZTUif19aNVU5raHE2xtA_5_2[0] = &TM__rmUZTUif19aNVU5raHE2xtA_0[11];
TM__rmUZTUif19aNVU5raHE2xtA_0[11].kind = 1;
TM__rmUZTUif19aNVU5raHE2xtA_0[11].offset = offsetof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg, n);
TM__rmUZTUif19aNVU5raHE2xtA_0[11].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__rmUZTUif19aNVU5raHE2xtA_0[11].name = "n";
TM__rmUZTUif19aNVU5raHE2xtA_5_2[1] = &TM__rmUZTUif19aNVU5raHE2xtA_0[12];
NTI__kmjEwko0gQNypI4MTa9chwQ_.size = sizeof(tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ);
NTI__kmjEwko0gQNypI4MTa9chwQ_.align = NIM_ALIGNOF(tyEnum_InstrKind__kmjEwko0gQNypI4MTa9chwQ);
NTI__kmjEwko0gQNypI4MTa9chwQ_.kind = 14;
NTI__kmjEwko0gQNypI4MTa9chwQ_.base = 0;
NTI__kmjEwko0gQNypI4MTa9chwQ_.flags = 3;
for (TM__rmUZTUif19aNVU5raHE2xtA_8 = 0; TM__rmUZTUif19aNVU5raHE2xtA_8 < 4; TM__rmUZTUif19aNVU5raHE2xtA_8++) {
TM__rmUZTUif19aNVU5raHE2xtA_0[TM__rmUZTUif19aNVU5raHE2xtA_8+13].kind = 1;
TM__rmUZTUif19aNVU5raHE2xtA_0[TM__rmUZTUif19aNVU5raHE2xtA_8+13].offset = TM__rmUZTUif19aNVU5raHE2xtA_8;
TM__rmUZTUif19aNVU5raHE2xtA_0[TM__rmUZTUif19aNVU5raHE2xtA_8+13].name = TM__rmUZTUif19aNVU5raHE2xtA_7[TM__rmUZTUif19aNVU5raHE2xtA_8];
TM__rmUZTUif19aNVU5raHE2xtA_6_4[TM__rmUZTUif19aNVU5raHE2xtA_8] = &TM__rmUZTUif19aNVU5raHE2xtA_0[TM__rmUZTUif19aNVU5raHE2xtA_8+13];
}
TM__rmUZTUif19aNVU5raHE2xtA_0[17].len = 4; TM__rmUZTUif19aNVU5raHE2xtA_0[17].kind = 2; TM__rmUZTUif19aNVU5raHE2xtA_0[17].sons = &TM__rmUZTUif19aNVU5raHE2xtA_6_4[0];
NTI__kmjEwko0gQNypI4MTa9chwQ_.node = &TM__rmUZTUif19aNVU5raHE2xtA_0[17];
TM__rmUZTUif19aNVU5raHE2xtA_0[12].kind = 3;
TM__rmUZTUif19aNVU5raHE2xtA_0[12].offset = offsetof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg, kind);
TM__rmUZTUif19aNVU5raHE2xtA_0[12].typ = (&NTI__kmjEwko0gQNypI4MTa9chwQ_);
TM__rmUZTUif19aNVU5raHE2xtA_0[12].name = "kind";
TM__rmUZTUif19aNVU5raHE2xtA_0[12].sons = &NimDT___Iclb1njvAJfjjEpCLzUzZg_kind[0];
TM__rmUZTUif19aNVU5raHE2xtA_0[12].len = 4;
TM__rmUZTUif19aNVU5raHE2xtA_0[18].kind = 1;
TM__rmUZTUif19aNVU5raHE2xtA_0[18].offset = offsetof(tyObject_Instr__Iclb1njvAJfjjEpCLzUzZg, dest);
TM__rmUZTUif19aNVU5raHE2xtA_0[18].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__rmUZTUif19aNVU5raHE2xtA_0[18].name = "dest";
NimDT___Iclb1njvAJfjjEpCLzUzZg_kind[0] = &TM__rmUZTUif19aNVU5raHE2xtA_0[18];
NimDT___Iclb1njvAJfjjEpCLzUzZg_kind[1] = &TM__rmUZTUif19aNVU5raHE2xtA_0[18];
TM__rmUZTUif19aNVU5raHE2xtA_0[19].len = 0; TM__rmUZTUif19aNVU5raHE2xtA_0[19].kind = 2;
NimDT___Iclb1njvAJfjjEpCLzUzZg_kind[4] = &TM__rmUZTUif19aNVU5raHE2xtA_0[19];
TM__rmUZTUif19aNVU5raHE2xtA_0[10].len = 2; TM__rmUZTUif19aNVU5raHE2xtA_0[10].kind = 2; TM__rmUZTUif19aNVU5raHE2xtA_0[10].sons = &TM__rmUZTUif19aNVU5raHE2xtA_5_2[0];
NTI__Iclb1njvAJfjjEpCLzUzZg_.node = &TM__rmUZTUif19aNVU5raHE2xtA_0[10];
NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_.size = sizeof(tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ*);
NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_.align = NIM_ALIGNOF(tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ*);
NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_.kind = 24;
NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_.base = (&NTI__Iclb1njvAJfjjEpCLzUzZg_);
NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_.flags = 2;
NTI__hj4BvueOlKB8Z1Qw2ZU4nQ_.marker = Marker_tySequence__hj4BvueOlKB8Z1Qw2ZU4nQ;
}

